@@ -17,22 +17,22 @@ knitr::kable(table(Books$label,clustering(sol)))
 K(sol)
 coef(sol)
 
-## ---- out.width="90%",fig.width=8,fig.height=8--------------------------------
-plot(sol, type='tree') # try also: type="path"
+## ---- out.width="90%",fig.width=8,fig.height=8,eval=FALSE---------------------
+#  plot(sol, type='tree') # try also: type="path"
 
 ## -----------------------------------------------------------------------------
 sol_K3 = cut(sol, K=3)
 K(sol_K3)
 knitr::kable(table(Books$label,clustering(sol_K3)))
 
-## ----plot,message=FALSE,results="hide", fig.show='hold', out.width="90%",fig.width=8,fig.height=8----
-plot(sol,type='blocks')
-plot(sol, type='nodelink')
+## ----plot,message=FALSE,results="hide", fig.show='hold', out.width="90%",fig.width=8,fig.height=8,eval=FALSE----
+#  plot(sol,type='blocks')
+#  plot(sol, type='nodelink')
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  available_models()
 
-## ----future-------------------------------------------------------------------
-library(future)
-plan(multisession, workers=2) # may be increased
+## ----future,eval=FALSE--------------------------------------------------------
+#  library(future)
+#  plan(multisession, workers=2) # may be increased
 
